//===----------------------------------------------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

// UNSUPPORTED: c++03

// <experimental/set>

#include <experimental/set>

#include "test_macros.h"

#ifndef _LIBCPP_VERSION
#error header must provide _LIBCPP_VERSION
#endif

int main(int, char**)
{

  return 0;
}
